# = Class: apache2
#
# Installe le serveur HTTP Apache2.
#
# == Actions:
#   - Installe le package apache2,
#   - Désactive le site par défaut,
#   - Configure le service apache2.
#   - Ajoute l'utilisateur www-data au groupe vagrant.
# 
# == Parameters:
#   Aucun.
#
# == Requires:
#   Rien.
#
# == Sampe Usage:
#
# class { "apache2": }
#
class apache2 {
    $config_dir = "/etc/apache2"

    File {
        ensure  => present,
        mode    => 00644,
        owner   => "root",
        group   => "root",
        require => Package["apache2"],
        notify  => Service["apache2"],
    }

    # Configuration pour l"utilisation des dossiers partages
    file { "sharedfolders":
        path   => "${config_dir}/conf.d/sharedfolders",
        source => "puppet:///modules/apache2/sharedfolders",
    }

    # Désactive le site par défaut
    exec { "a2dissite default":
        command => "/usr/sbin/a2dissite default",
        onlyif  => "/usr/bin/test -h ${config_dir}/sites-enabled/000-default",
        require => Package["apache2"],
        notify  => Service["apache2"],
    }
    
    # Le package
    package { "apache2":
        ensure => present
    }
    
    # Le service
    service { "apache2":
        ensure     => running,
        enable     => true,
        hasrestart => true,
        hasstatus  => true,
        require    => Package["apache2"]
    }

    # Permet à l'utilisateur d'Apache d'accéder aux fichiers du groupe vagrant
    user { "www-data":
        groups   => [ "vagrant" ],
        require  => Package["apache2"]
    }

}
