# = Resource: apache2::module
#
# Configure un module Apache2.
# 
# == Actions:
#   - Installe le module si nécessaire.
#   - Installe la configuration.
#   - Active ou désactive le module.
#
# == Parameters:
#
# $enabled:: true pour installer et activer le module, false pour le désactive.
#
# $package:: Nom du package à installer. Utiliser false si le module fait partie
#            des modules de base.
#
# $conf_source:: Source àutilser pour le fichier de configuration.
#
# $conf_content:: Contenu du fichier de configuration.
#
# == Requires:
#   - Class['apache2']
#
# == Sampe Usage:
#
# Installe le module mod_rpaf:
#  apache2::module { "rpaf":}
#
# Désactive le module rewrite distribué avec Apache2:
# apache2::module { "rewrite":
#   enabled => false,
#   package => false,
# }
#
define apache2::module (
    $enabled      = true,
    $package      = "libapache2-mod-${name}",
    $conf_source  = undef,
    $conf_content = undef
) {	
    include apache2
    
    if $enabled {
        
        if $package {
            package { $package:
                require => Package["apache2"],
                notify  => Service["apache2"],
            } -> Exec["a2enmod $name"]
        }
        
        if $conf_source or $conf_content {
            file { "${name}.conf":
                ensure  => present,
                path    => "${apache2::config_dir}/mods-available/${name}.conf",
                source  => $conf_source,
                content => $conf_content,
            } -> Exec["a2enmod $name"]
        }
        
        exec { "a2enmod $name":
            command => "/usr/sbin/a2enmod '${name}'",
            unless  => "/usr/bin/test -e ${apache2::config_dir}/mods-enabled/${name}.load",
            require => Package["apache2"],
            notify  => Service["apache2"],
        }
        
    } else {

        exec { "a2dismod $name":
            command => "/usr/sbin/a2dismod '${name}'",
            onlyif  => "/usr/bin/test -e ${apache2::config_dir}/mods-enabled/${name}.load",
            require => Package["apache2"],
            notify  => Service["apache2"],
        }
    }

}
