# = Resource: apache2::site
#
# Configure un site Apache2.
#
# == Actions:
#   - Met en place la configuration dans site-available,
#   - Active le site.
# 
# == Parameters:
#   $enabled:: true pour activer le site ou false le désactiver.
#
#   $source:: Fichier contenant la configuration (optionnel).
#
#   $content:: Source de la configuration (optionnel).
#
# == Requires:
#   - Class["apache2"]
#
# == Sampe Usage:
#
# apache2::site { "": }
#
define apache2::site (
    $enabled = true,
    $source  = undef,
    $content = undef
) {
    include apache2

    file { "available-site-${name}":
        ensure  => present,
        path    => "${apache2::config_dir}/sites-available/${name}",
        source  => $source,
        content => $content,
        require => Package["apache2"],
        notify  => Service["apache2"],		
    }
    
    file { "enabled-site-${name}":
        ensure  => $enabled ? {
            true  => link,
            false => absent
        },
        path    => "${apache2::config_dir}/sites-enabled/${name}",
        target  => "../sites-available/${name}",
        require => File["available-site-${name}"],
    }
    
} 