# = Class: irstea::base
#
# Configuration de base d'une machine de dev Pôle IS.
#
# == Actions:
#   - Utilise le miroir APT de Lyon.
#   - Installe les packages less, most, vim, htop et command-not-found.
#   - Installe des configurations pratiques pour vim et bash.
#
# == Parameters:
#   Aucun.
#
# == Requires:
#
class irstea::base {

    # Outils et commands pratiques
    package { ["bash", "less", "most", "vim", "htop", "command-not-found"]: }

    # Configuration
    File {
        owner => "root", 
        group => "root",
        mode  => 00644
    }

    # Configuration outils et terminal
    file { "/etc/inputrc":     
        source => "puppet:///modules/irstea/base/inputrc" 
    }

    file { "/etc/vim/vimrc":   
        source  => "puppet:///modules/irstea/base/vimrc",
        require => Package['vim']
    }
    
    file { "/etc/bash.bashrc":
        source  => "puppet:///modules/irstea/base/bash.bashrc",
        require => Package['bash']
    }
    
    file { "/home/vagrant/.bashrc":
        content => "[ -f /etc/bash.bashrc ] && . /etc/bash.bashrc",
        owner   => "vagrant",
        group   => "vagrant",
        require => File["/etc/bash.bashrc"]
    }
    
    # Met à jour "command-not-found" de temps en temps
    exec { "update-command-not-found":
        command => "/usr/sbin/update-command-not-found",
        creates => "/var/cache/command-not-found/main.db",
        require => Package['command-not-found']
    }

    # Nécessaire pour une bonne execution de Puppet
    user { "vagrant": groups => [ "adm" ] }
    group { "puppet": }

    # Met à jour APT, pas plus d'une fois par jour
    schedule { daily: period => daily }
    exec { "apt-update":
        command  => "/usr/bin/apt-get update",
        schedule => daily,
    }

    # Met en place l'ordre d'éxecution
    Exec["apt-update"] -> Package <| |>

    # Backup les fichiers modifies dans le meme repertoire
    File <| |> { backup => ".puppet-bak" }
}
