# = Class: irstea::copix3
#
# Préconfiguration IRSTEA.
#
# Etend la classe irstea.
#
# == Actions:
#   - Installe le site appli-copix3.
#   - Ajoute un fichier de config PHP5 irstea.ini.
#   - Met en place les fichiers de config Copix3 dans project/config
#     et var/config à partir des versions .default ; sauf pour la base de données.
#   - Crée une base de données vide.
#
# == Parameters:
#   cf. irstea::parameters
#
# == Requires:
#   - Class['irstea']
#
class irstea::copix3 inherits irstea {

    # Site pour Copix3
    apache2::site { "appli-copix3":
        source => "puppet:///modules/irstea/appli-copix3",	
        require => File[$app_root],
    }

    # Configuration PHP5 adaptée
    $short_open_tag = true
    php5::config { "irstea.ini":
        content => template("irstea/php.ini.erb")
    }

    # Fichiers de configuration par défaut
    irstea::copix3::configfile { [
        "project/config/copix",
        "project/config/path",
        "var/config/user_handlers",
        "var/config/group_handlers",
        "var/config/credential_handlers",
        "var/config/plugins",
        "var/config/cache_profiles",
    ]: }
    
    # Création de la base de données vide
    postgresql::database { $database:
        owner => $dbuser,
    }

}
