# = Class: irstea
#
# Préconfiguration IRSTEA.
#
# == Actions:
#   - Installe apache2, postgresql, memcached et php5.
#   - Installe les modules PHP5 ldap, gd et xdebug,
#   - Crée le répertoire /var/www/appli,
#   - Crée l'utilisateur PostgreSQL $dbuser,
#   - Met à jour APT (apt-update).
#   - Crée le groupe "puppet" et place l'utilisateur "vagrant" dans le groupe "adm" (accès aux logs).
#
# == Parameters:
#   cf. irstea::parameters
#
# == Requires:
#   - Class['irstea::base']
#   - Class['apache2']
#   - Class['postgresql']
#   - Class['memcached']
#   - Class['php5']
#
class irstea inherits irstea::parameters {
    # Réglage de base
    include irstea::base

    # Les au
    include apache2
    include postgresql
    include memcached
    include php5

    # Modules PHP supplémentaires
    php5::module { ["ldap", "gd", "xdebug"]: }

    # Répertoire racine de l'application
    file { $app_root:
        alias   => "/var/www/appli",
        ensure  => directory,
        require => Package['apache2'],
    }

    # Utilisateur postgresql www-data
    postgresql::user { $dbuser:
        createdb => true
    }

}

