# = Class: irstea::symfony14
#
# Préconfiguration Symfony 1.4.
#
# Etend la classe irstea::symfony.
#
# == Actions:
#   - Installe le module PHP5 XSL.
#   - Installe le site Apache2 apply-symfony.
#   - Créé les répertoires /var/cache/symfony et /var/log/symfony et ...
#   - ... fait pointer /var/www/appli/cache et /var/www/appli/log sur ces répertoires,
#   - Fait une copie locale (via rsync) de /var/www/appli/lib/vendor/symfony dans /var/lib/symfony et ...
#   - ... fait pointer /var/www/appli/lib/vendor/symfony sur /var/lib/symfony.
#   - Execute "symfony configure:database".
#   - Execute "symfony doctrine:build --all --and-load".
#
# == Parameters:
#   cf. irstea::parameters
#
# == Requires:
#   - Class['irstea::symfony']
#
class irstea::symfony14 inherits irstea::symfony {

    # Modules PHP5 supplémentaires
    php5::module { "xsl": }
    
    # Site pour symfony
    apache2::site { "appli-symfony":
        source => "puppet:///modules/irstea/appli-symfony14",
        require => File[$app_root],
    }
    
    # Répertoires supplémentaires
    file { ["/var/cache/symfony", "/var/log/symfony"]:
        ensure => directory,
        owner  => "vagrant",
        group  => "www-data",		
        mode   => 00775,
    }
    
    package { "rsync": }
    
    exec { "/var/lib/symfony":
        command => "/usr/bin/rsync -a --exclude='*.svn' '${app_root}/lib/vendor/symfony' /var/lib",
        creates => "/var/lib/symfony",
        require => Package["rsync"],
    }
    
    mount { "${app_root}/cache":
        ensure   => mounted,
        fstype   => "ext4",
        options  => "bind",
        device   => "/var/cache/symfony",
        atboot   => false,
        require  => File["/var/cache/symfony"],
    }

    mount { "${app_root}/log":
        ensure   => mounted,
        fstype   => "ext4",
        options  => "bind",
        device   => "/var/log/symfony",
        atboot   => false,
        require  => File["/var/log/symfony"],
    }
    
    mount { "${app_root}/lib/vendor/symfony":
        ensure   => mounted,
        fstype   => "ext4",
        options  => "bind",
        device   => "/var/lib/symfony",
        atboot   => false,
        require  => Exec["/var/lib/symfony"],
    }
    
    # Configuration de la base de données Symfony
    exec { "symfony configure:database":
        command   => "${app_root}/symfony configure:database pgsql:dbname=${database}\\;host=/var/run/postgresql ${dbuser}",
        creates   => "${app_root}/config/databases.yml",
        logoutput => true,
        user      => "vagrant",
        group     => "www-data",
        require   => Postgresql::User[$dbuser]
    }
    
    # Dépendances
    Exec["symfony configure:database"] <- Php5::Config <| |>
    Exec["symfony configure:database"] <- Php5::Module <| |>
    Exec["symfony configure:database"] <- Php5::Pear::Package <| |>

    # Génération de la base de données Symfony
    exec { "symfony doctrine:build --all --and-load":
        command   => "${app_root}/symfony doctrine:build --all --and-load --no-confirmation",
        unless    => "/usr/bin/psql -c 'select tableowner from pg_tables' ${database} '${dbuser}' | /bin/fgrep '${dbuser}'",
        logoutput => true,
        user      => "vagrant",
        group     => "www-data",
        require   => Exec["symfony configure:database"],
    }

}
