# = Class: irstea::symfony14
#
# Préconfiguration Symfony 1.4.
#
# Etend la classe irstea::symfony.
#
# == Actions:
#   - Installe le module PHP5 xsl, sqlite et intl.
#   - Installe le site Apache2 apply-symfony.
#   - Installe package PEAR PHPUnit.
#   - Installe les vendors.
#   - Génère un fichier parameters.ini.
#   - Créé les répertoires /var/cache/symfony et /var/log/symfony et ...
#   - ... fait pointer /var/www/appli/app/cache et /var/www/appli/app/logs sur ces répertoires,
#   - Fait une copie locale (via rsync) de /var/www/appli/lib/vendor dans /var/lib/symfony et ...
#   - ... fait pointer /var/www/appli/lib/vendor sur /var/lib/symfony.
#   - Execute "app/console doctrine:database:create".
#   - Execute "app/console doctrine:schema:create".
#   - Execute "app/console doctrine:fixtures:load --fixtures='${fixtureBundle}'".
#
# == Parameters:
#   $fixtureBundle:: Nom du Bundle contenant les données intiales à charger.
#
#   cf. irstea::parameters
#
# == Requires:
#   - Class['irstea::symfony']
#
class irstea::symfony20 (
    $fixtureBundle = undef
) inherits irstea::symfony {

    # Modules PHP5 supplémentaires
    php5::module { ["xsl", "sqlite", "intl"]: }

    # Site pour symfony
    apache2::site { "appli-symfony":
        source => "puppet:///modules/irstea/appli-symfony20",
        require => File[$app_root],
    }

    # Nécessaire pour certains scripts
    package { "git": }
    
    # Config par défaut
    file { "parameters.ini":
        ensure  => present,
        path    => "${app_root}/app/config/parameters.ini",
        content => template("irstea/symfony20/parameters.ini.erb"),
        require => File[$app_root],
    }

    # Canaux PEAR
    php5::pear::channel { "symfony": channel => "pear.symfony-project.com" }
    php5::pear::channel { "ezc":     channel => "components.ez.no" }
    php5::pear::channel { "phpunit": channel => "pear.phpunit.de" }

    # Installation de PHPUnit
    php5::pear::package { "phpunit/PHPUnit": }
    
    # Répertoires supplémentaires
    file { ["/var/cache/symfony", "/var/log/symfony"]:
        ensure => directory,
        owner  => "vagrant",
        group  => "www-data",
        mode   => 00775,
    }

    # Montage de ces répertoires
    mount { "${app_root}/app/cache":
        ensure   => mounted,
        fstype   => "ext4",
        options  => "bind",
        device   => "/var/cache/symfony",
        atboot   => false,
        require  => File["/var/cache/symfony"],
    }

    mount { "${app_root}/app/logs":
        ensure   => mounted,
        fstype   => "ext4",
        options  => "bind",
        device   => "/var/log/symfony",
        atboot   => false,
        require  => File["/var/log/symfony"],
    }
    
    # Installe les librairies externes
    exec { "install-vendors":
        command   => "${app_root}/bin/vendors install",
        unless    => "/bin/ls ${app_root}/vendor/* >/dev/null 2>&1",
        cwd       => $app_root,
        timeout   => 0,
        logoutput => true,
        require   => [
            Package["git"],
            File["parameters.ini"],
        ],
        user      => "vagrant",
        group     => "www-data",
    }
    # Dépendances
    Exec["install-vendors"] <- Php5::Config <| |>
    Exec["install-vendors"] <- Php5::Module <| |>
    Exec["install-vendors"] <- Php5::Pear::Package <| |>
    
    # Fait une copie locale des vendors
    package { "rsync": }	
    exec { "/var/lib/symfony":
        command => "/usr/bin/rsync -a --exclude='*.svn' '${app_root}/vendor/' /var/lib/symfony",
        creates => "/var/lib/symfony",
        require => Exec["install-vendors"],
    }
    
    # Utilise la copie locale
    mount { "${app_root}/vendor":
        ensure   => mounted,
        fstype   => "ext4",
        options  => "bind",
        device   => "/var/lib/symfony",
        require  => Exec["/var/lib/symfony"],
    }
    
    # Charge une base de données initiaile
    exec { "create-database":
        command => "${app_root}/app/console doctrine:database:create && ${app_root}/app/console doctrine:schema:create && ${app_root}/app/console doctrine:fixtures:load --fixtures='${fixtureBundle}'",
        cwd     => $app_root,
        unless  => "/usr/bin/psql -c 'select datname from pg_database' template1 ${dbuser} | /bin/fgrep '${database}'",
        logoutput => true,
        user    => "vagrant",
        group   => "www-data",
        require => Mount["${app_root}/vendor"]
    }

}
