# = Resource: postgresql::database
#
# Créé une base de données dans PostgreSQL.
#
# == Actions:
#   - Créé la base de données dans PostgreSQL.
# 
# == Parameters:
#   $name:: Nom de la base de données.
#
#   $encoding:: Encodage des chaînes (optionnel, "UTF8").
#
#   $template:: Base de données modèle (optionnel, "template0").
#
#   $owner:: propriétaire de la base (optionnel, "postgres").
#
#   $locale:: Langue de la base (optionnel).
#
# == Requires:
#   - Class['postgresql'].
#
# == Sampe Usage:
#
# Créé une base de données "mydatabase":
#   postgresql::database { "mydatabase": }
#
define postgresql::database(
    $encoding = 'UTF8',
    $template = 'template0',
    $owner    = 'postgres',
    $locale   = undef
) {
    include postgresql

    if $locale {
        $locale_opt = "--locale='${locale}'"
    } else {
        $locale_opt = ""
    }
    
    exec { "database-${title}":
        command => "/usr/bin/createdb ${locale_opt} -E '${encoding}' -O '${owner}' -T '${template}' '${title}'",
        unless  => "/usr/bin/psql -q -t -c 'select datname from pg_database' | /bin/fgrep '${title}'",
        require => Postgresql::User[$owner],
        user => "postgres",
        group => "postgres",
    }
    
}
