# = Class: postgresql
#
# Installe le SGBD PostgreSQL.
#
# == Actions:
#   - Installe le package postgresql.
#   - Configure tous les accès en "trusted".
#   - Active le socket TCP/IP sur toutes les interfaces.
# 
# == Parameters:
#   Aucun.
#
# == Requires:
#   Rien.
#
# == Sampe Usage:
#
# class { "postgresql": }
#
class postgresql {

    if $operatingsystem == "Debian" {
        $version = $operatingsystemrelease ? {
            /^6\./  => "8.4",
            default => undef
        }
    }
    
    package { "postgresql": }
    
    file { "/etc/postgresql/${version}/main/pg_hba.conf":
        ensure  => present,
        source  => "puppet:///modules/postgresql/pg_hba.conf",
        owner   => "postgres",
        group   => "postgres",
        mode    => 0640,
        require => Package["postgresql"],
        notify  => Service["postgresql"],
    }

    exec { "enable tcp/ip socket":
        command => "/bin/sed -ie \"s/#listen_addresses = 'localhost'/listen_addresses = '*'/\" /etc/postgresql/${version}/main/postgresql.conf",
        unless => "/bin/egrep '^listen_addresses =' /etc/postgresql/${version}/main/postgresql.conf",
        require => Package["postgresql"],
        notify  => Service["postgresql"],
    }
    
    service { "postgresql":
        ensure     => running,
        enable     => true,
        hasrestart => true,
        hasstatus  => true,
        require    => Package["postgresql"],
    }
    
}