# = Resource: postgresql::user
#
# Créé une utilisateur dans PostgreSQL.
#
# == Actions:
#   - Créé l'utilisateur dans PostgreSQL.
# 
# == Parameters:
#   $name:: Nom de l'utilisateur.
#
#   $password:: Mot de passe en clair (optionnel, aucun).
#
#   $createdb:: CREATEDB (optionnel, false).
#
#   $createrole:: CREATEROLE ?(optionnel, false).
#
#   $superuser:: SUPERUSER ? (optionnel, false).
#
#   $login:: LOGIN ? (optionnel, true).
#
#   $inherit:: INHERIT ? (optionnel, true).
#
# == Requires:
#   - Class['postgresql'].
#
# == Sampe Usage:
#
# Créé un utilisateur "www-data":
#   postgresql::user { "www-data": }
#
define postgresql::user(
    $password   = undef,
    $createdb   = false,
    $createrole = false,
    $superuser  = false,
    $login      = true,
    $inherit    = true
) {
    include postgresql

    if $createdb {
        $createdb_opts = "-d"
    } else {
        $createdb_opts = "-D"
    }

    if $createrole {
        $createrole_opts = "-r"
    } else {
        $createrole_opts = "-R"
    }
    
    if $superuser {
        $superuser_opts = "-s"
    } else {
        $superuser_opts = "-S"
    }	

    if $inherit {
        $inherit_opts = "-i"
    } else {
        $inherit_opts = "-I"
    }	

    if $login {
        $login_opts = "-l"
    } else {
        $login_opts = "-L"
    }	
    
    if $password {
        $password_opts = "-N '${password}'"
    } else {
        $password_opts = ""
    }

    exec { "createuser-${title}":
        command => "/usr/bin/createuser ${createdb_opts} ${createrole_opts} ${inherit_opts} ${superuser_opts} ${$login_opts} ${$password_opts} '${title}'",
        unless => "/usr/bin/psql -q -t -c 'select usename from pg_user' | /bin/fgrep '${title}'",
        require => Package["postgresql"],
        user => "postgres",
        group => "postgres",
    }
    
}